import 'dart:async';

import 'package:get_it/get_it.dart';
import 'package:starting_template/core/enums/data_source_type.dart';
import 'package:starting_template/core/logger/app_logger.dart';
import 'package:starting_template/core/utils/env.dart';

final getIt = GetIt.I;

/// Service and Data Source locator
abstract class GetItInitializer {
  static AppLogger get logger => AppLogger('GetItInitializer');

  static FutureOr<void> _initCommon() async {
    logger.info('Initializing common sources/services');
  }

  static FutureOr<void> _initMock() async {
    logger.info('Initializing mock sources');
  }

  static FutureOr<void> _initApi() async {
    logger.info('Initializing API sources');
  }

  static FutureOr<void> _initRepositories() async {
    logger.info('Initializing repositories');
  }

  static FutureOr<void> _initUseCases() async {
    logger.info('Initializing use cases');
  }

  static FutureOr<void> init() async {
    // Initialize common sources/services
    await _initCommon();

    // Initialize sources/services based on data source type
    switch (Env.dataSource) {
      case DataSourceType.mock:
        await _initMock();
        break;
      case DataSourceType.api:
        await _initApi();
        break;
    }

    // Initialize repositories
    await _initRepositories();

    // Initialize use cases
    await _initUseCases();

    await getIt.allReady();
  }
}
