import 'package:flutter/cupertino.dart';
import 'package:{{#snakeCase}}{{project_name}}{{/snakeCase}}/presentation/features/home/home.dart';
import 'package:wyatt_go_router/wyatt_go_router.dart';

abstract class AppRouter {
  /// Default transition for all pages
  static Page<void> defaultTransition(
    BuildContext context,
    GoRouterState state,
    Widget child,
  ) =>
      CupertinoPage<void>(key: state.pageKey, child: child);

  /// Disable transition animation
  static Page<void> noTransition(
    BuildContext context,
    GoRouterState state,
    Widget child,
  ) =>
      NoTransitionPage(key: state.pageKey, child: child);

  /// Defines GoRoute routes.
  static final List<GoRoute> routes = [
    GoRoute(
      path: '/',
      name: Home.pageName,
      pageBuilder: (context, state) =>
          defaultTransition(context, state, const Home()),
    )..setPublic(),
  ];

  /// Singleton instance of [GoRouter]
  static GoRouter? _router;

  /// Navigator key for the root navigator
  static final GlobalKey<NavigatorState> rootNavigatorKey =
      GlobalKey<NavigatorState>();

  /// Router
  static GoRouter routerOf(BuildContext context) => _router ??= GoRouter(
        initialLocation: '/',
        routes: AppRouter.routes,
        navigatorKey: rootNavigatorKey,
        debugLogDiagnostics: true,
        refreshListenable: GoRouterRefreshStream(const Stream.empty()),
        // TODO(wyatt): Add authentication logic
        redirect: (context, state) {
          /// Define the default guard
          /// This is the guard that will be used if the route
          /// does not have a guard set. (It is set to [PageProtection.none])
          const defaultProtection = PageProtection.protected;

          /// Get the current route
          final currentRoute = context.currentRoute;

          /// Get the guard of the current route
          final _ = (currentRoute.protection == PageProtection.none)
              ? defaultProtection
              : currentRoute.protection;

          return null;
        },
      );
}
